@@ -6,6 +6,7 @@ lslx$set("public",
                   delta,
                   step,
                   standard_error = "default",
+                  ridge_penalty = "default",
                   debias = "default",
                   inference = "default",
                   alpha_level = .05,
@@ -95,6 +96,13 @@ lslx$set("public",
                standard_error <- "observed_information"
              }
            }
+           if (ridge_penalty == "default") {
+             if (private$fitting$control$penalty_method %in% c("ridge", "elastic_net")) {
+               ridge_penalty <- TRUE
+             } else {
+               ridge_penalty <- FALSE
+             }
+           }
            ##generating output informations
            if (output$general_information) {
              general_information <-
@@ -441,6 +449,7 @@ lslx$set("public",
                  delta = delta,
                  step = step,
                  standard_error = standard_error,
+                 ridge_penalty = ridge_penalty,
                  alpha_level = alpha_level,
                  debias = debias,
                  inference = inference,
@@ -584,7 +593,7 @@ lslx$set("public",
                      "estimate",
                      "std.error",
                      "z-value",
-                     "p-value",
+                     "P(>|z|)",
                      "lower",
                      "upper",
                      "block_label"
